@@ -16,11 +16,7 @@ pub async fn fetch_html_record(url_str: &str) -> Result<HtmlRecord, reqwest::Err
     headers_map.insert(String::from("status"), status_value);
 
     let body_value = res.text().await?;
-    let record: HtmlRecord = HtmlRecord {
-        origin: url_parsed.to_string(),
-        headers: headers_map,
-        body: body_value,
-    };
+    let record: HtmlRecord = HtmlRecord::new(url_parsed.to_string(), headers_map, body_value);
 
     Ok(record)
 }
