@@ -1,8 +1,6 @@
-use std::fmt::Error;
 use std::fs;
-use std::io::{ErrorKind, Read, Write};
+use std::io::{Read, Write};
 use std::net::{TcpListener, TcpStream};
-
 pub struct TestServer {}
 
 impl TestServer {
